# To close budget on particles

The way to close tracer budget on Lagrangian particles is relatively easy. Please referred to the functions in eulerian_budget and lagrangian_budget. So far, I have not gotten the time to make an illustrative example, but the api references are ready to go.

If you would like to use this functionality but have some difficulties, please email me (Wenrui Jiang) at wjiang33@jhu.edu. I am happy to share my code, explain things, and potentially get more involved on your project.

If you want to contribute to the package by helping me make the budget code public, also email me. I don't know how to thank you enough.
